#include "tangle/tangle-misc.h"

int main(int argc, char** argv) {
	GValue a = { 0 };
	GValue b = { 0 };
	
	tangle_init(&argc, &argv);
	
	g_value_init(&a, G_TYPE_FLOAT);
	g_value_set_float(&a, 2.0);

	g_value_init(&b, G_TYPE_FLOAT);
	g_value_set_float(&b, 3.0);
	
	tangle_value_divide(&a, &b);
	
	g_print("%d %f %d\n", tangle_value_is_calculation_supported(G_TYPE_FLOAT), g_value_get_float(&a), tangle_value_compare(&a, &b));
	
	return 0;
}
